<?php

namespace Litecms\Exporter\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Exporter\Events\YardiAction as YardiActionEvent;
use Litecms\Exporter\Notifications\YardiAction as YardiActionNotification;
use Litepie\Actions\Concerns\AsAction;

class YardiAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the YardiActionEvent.
     *
     * @param   YardiActionEvent  $event
     * @return mixed
     */
    public function handle(YardiActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $yardi.
     *
     * @param   YardiActionEvent  $event
     * @return void
     */
    public function create(YardiActionEvent $event)
    {
        $client = $event->yardi->client;
        Notification::send($client, new YardiActionNotification($event));
    }

    /**
     * Handle the YardiActionEvent as a listener.
     *
     * @param   YardiActionEvent  $event
     * @return mixed
     */
    public function asListener(YardiActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   YardiActionEvent  $event
     * @return bool
     */
    private function isAllowed(YardiActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
