<?php

namespace Litecms\Exporter\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Exporter\Events\YardiWorkflow as YardiWorkflowEvent;
use Litecms\Exporter\Notifications\YardiWorkflow as YardiWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class YardiWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(YardiWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $yardi is submitted.
     *
     * @param YardiWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(YardiWorkflowEvent $event)
    {
        $client = $event->yardi->client;
        Notification::send($client, new YardiWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $yardi is published.
     *
     * @param YardiWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(YardiWorkflowEvent $event)
    {
        $client = $event->yardi->client;
        Notification::send($client, new YardiWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $yardi is approved.
     *
     * @param YardiWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(YardiWorkflowEvent $event)
    {
        $client = $event->yardi->client;
        Notification::send($client, new YardiWorkflowNotification($event));
    }

    /**
     * Handles the $yardi workflow event as a listener.
     *
     * @param YardiWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(YardiWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
